.. cavcalc documentation master file

.. only:: latex

    =======
    cavcalc
    =======

.. only:: not latex

    .. figure:: images/logo_cavcalc.png
        :align: center

.. note:: These documentation pages are still under construction and are subject
          to large changes whilst cavcalc is going through active development.

The program `cavcalc` is a convenient tool for computing parameters associated
with Fabry-Perot style optical cavities. The recommended way to use
cavcalc is to invoke it via the command line, however a Python API
is also exposed such that it can be used in the same way as any other
Python module.

Installation is simple, just run::

    pip install --upgrade cavcalc

to install the latest release version of cavcalc.

----

.. toctree::
    :maxdepth: 1
    :name: sec-usage

    using/index
    api/cavcalc
    details/index
